@@ -1,5 +1,4 @@
-/* Yo Emacs, this -*- C++ -*-
-
+/*
   Copyright (C) 1999-2001 Jens Hoefkens
   jens@hoefkens.com
 
@@ -28,7 +27,7 @@
 #include <config.h>
 #endif 
 
-#include <kplayer.h>
+#include <kgame/kplayer.h>
 #include <tqdatastream.h> 
 
 class KGame;
