@@ -1,4 +1,4 @@
-/* Yo Emacs, this is -*- C++ -*-
+/*
  *******************************************************************
  *******************************************************************
  *
@@ -42,7 +42,7 @@
 #include <tdeconfig.h>
 #include <tdeaction.h>
 #include <kstdgameaction.h>
-#include <khighscore.h>
+#include <highscore/khighscore.h>
 #include <kdebug.h>
 #include <kkeydialog.h>
 #include <tdepopupmenu.h>
