@@ -1,7 +1,7 @@
 #ifndef COMMON_INTER_H
 #define COMMON_INTER_H
 
-#include <kexthighscore.h>
+#include <highscore/kexthighscore.h>
 #include "lib/libksirtet_export.h"
 
 #include "lib/mp_simple_interface.h"
